pub struct BrewAction { /* private fields */ }Expand description
BrewAction Installs software using homebrew.
Implementations
Sourceimpl BrewAction
impl BrewAction
Sourcepub fn skip_in_ci(&self) -> &bool
pub fn skip_in_ci(&self) -> &bool
Skips this action if it is running in a CI environment.
Sourcepub fn force_casks(&self) -> &bool
pub fn force_casks(&self) -> &bool
Passes --force to brew install --cask.
Sourcepub fn adopt_casks(&self) -> &bool
pub fn adopt_casks(&self) -> &bool
when the app is already installed before the cask install.
Sourcepub fn auto_trust_taps(&self) -> &bool
pub fn auto_trust_taps(&self) -> &bool
Automatically run brew trust on any custom taps.